<h1 id="kipoi.install_model_requirements">install_model_requirements</h1>

```python
install_model_requirements(model, source='kipoi', and_dataloaders=True)
```
Install model dependencies

__Arguments__

- __model (str)__: model name
- __source (str)__: model source
- __and_dataloaders (bool)__: if True, install also the dependencies
        for the default dataloader

<h1 id="kipoi.install_dataloader_requirements">install_dataloader_requirements</h1>

```python
install_dataloader_requirements(dataloader, source='kipoi')
```
Install dataloader dependencies

__Arguments__

- __datalaoder (str)__: dataloader name
- __source (str)__: model source

